# Running the Experiments

## Installation

To install all packages used for the experiments, you should use a fresh virtual environment and Python 3.6 or higher. Installation of the packages can then be done with `pip`:
```
$ pip install -r requirements.txt
```

## Running the Code

The code consists of Python scripts called `run.py` in all subfolders. It is assumed that you open the terminal from within each folder (`example-1`, `example-2`, `example-3`) and then type:

```
$ python run.py
```


